@@ -36,7 +36,8 @@ def _check_line_label_list(maxErrorA = 5.e-3, maxErrorm = 5.e-2):
             
 LINE_LABEL_LIST = {}
 LINE_LABEL_LIST['H1r'] = ['1216A', '1026A', '973A', '6563A', '4861A', '4341A', '4102A', '3970A', '3889A',
-                           '3835A', '3798A', '1.87m', '1.28m', '1.09m', '9546A', '9229A']
+                           '3835A', '3798A', '1.87m', '1.28m', '1.09m', '9546A', '9229A', '8750A','8863A',
+                           '9015A']
 LINE_LABEL_LIST['He1r'] = ['5876A', '2945A', '3188A', '3614A', '3889A', '3965A', '4026A', '4121A', '4388A',
                           '4438A', '4471A', '4713A', '4922A', '5016A', '5048A', '5876A', '6678A', '7065A',
                           '7281A', '9464A', '10830A', '11013A', '11969A', '12527A', '12756A', '12785A',
@@ -61,6 +62,22 @@ LINE_LABEL_LIST['C1'] = ['9808A', '9824A', '9850A', '4618A', '4621A', '4627A', '
 LINE_LABEL_LIST['C2'] = ['2325A', '2328A', '2323A', '2327A', '2322A', '2325A', '1335A', '1336A', '3131A', '3133A', 
                          '3136A', '1036A', '1037A', '1869A', '1870A', '1871A', '4636A', '4637A', '157.6m', '454.4m', 
                          '198.8m', '353.3m', '3967.2m']
+LINE_LABEL_LIST['C2r'] =  ['9903+', '4267+', '7231+', '6580+', '2837+', '1761+', '1335+',
+                           '11641.0A', '4156.0A', '1632.0A', '40292.0A', '21809.0A', '12774.0A',
+                           '7572.0A', '7508.0A', '4292.0A', '2140.0A', '1653.0A', '68870.0A',
+                           '28127.0A', '14709.0A', '8213.0A', '14565.0A', '8138.0A', '4491.0A',
+                           '4329.0A', '2189.0A', '1682.0A', '4463.0A', '47268.0A', '18662.0A',
+                           '9314.0A', '46443.0A', '18451.0A', '9224.0A', '4803.0A', '8869.0A',
+                           '4619.0A', '2261.0A', '8268.0A', '4752.0A', '30688.0A', '11579.0A',
+                           '30154.0A', '11444.0A', '5342.0A', '10931.0A', '5122.0A', '2375.0A',
+                           '4019.0A', '1796.0A', '18516.0A', '18199.0A', '6462.0A', '17000.0A',
+                           '6151.0A', '2575.0A', '914.0A', '4639.0A', '1910.0A', '1505.0A',
+                           '1157.0A', '9903.0A', '9230.0A', '2993.0A', '962.0A', '31211.0A',
+                           '6259.0A', '2138.0A', '10301.0A', '997.0A', '1548.0A', '1270.0A',
+                           '4267.0A', '1064.0A', '17847.0A', '2747.0A', '5890.0A', '2174.0A',
+                           '1142.0A', '1930.0A', '3920.0A', '7235.0A', '6580.0A', '1762.0A',
+                           '2841.0A', '1760.0A', '5060.0A', '3176.0A', '1232.0A', '1335.0A',
+                           '1037.0A', '1324.0A', '1066.0A', '1721.0A']
 LINE_LABEL_LIST['C3'] = ['1910A', '1909A', '1907A', '977A', '2000A', '2001A', '2003A', '422.0m', '124.9m', '177.4m']
 LINE_LABEL_LIST['C4'] = ['1551A', '1548A', '92.8m']
 LINE_LABEL_LIST['Ca2'] = ['7292A', '7324A']
@@ -90,6 +107,16 @@ LINE_LABEL_LIST['Mg7'] = ['2441A', '2509A', '2629A', '1174A', '1190A', '1216A',
 LINE_LABEL_LIST['N1'] = ['5200A', '5198A', '3467A', '3466A']
 LINE_LABEL_LIST['N2'] = ['6527A', '6548A', '6584A', '3058A', '3063A', '3071A', '5755A', '2137A', '2139A', '2143A', 
                          '3177A', '7092A', '205.3m', '76.4m', '121.8m']
+LINE_LABEL_LIST['N2r'] = ['4026.08A', '4035.08A', '4039.35A', '4041.31A', '4043.53A', '4044.78A',
+                          '4056.90A', '4058.16A', '4073.04A', '4076.91A', '4077.40A', '4082.27A',
+                          '4082.89A', '4086.83A', '4087.30A', '4095.90A', '4096.58A', '4100.97A',
+                          '4601.48A', '4607.16A', '4613.87A', '4621.39A', '4630.54A', '4643.09A',
+                          '4774.24A', '4779.72A', '4781.19A', '4788.13A', '4793.65A', '4803.29A',
+                          '4810.31A', '5001.14A', '5001.48A', '5005.15A', '5016.39A', '5025.66A',
+                          '5040.72A', '5452.08A', '5454.22A', '5462.59A', '5478.10A', '5480.06A',
+                          '5495.67A', '5666.63A', '5676.02A', '5679.56A', '5686.21A', '5710.77A',
+                          '5730.65A', '5927.81A', '5931.78A', '5940.24A', '5941.65A', '5952.39A',
+                          '5960.90A']
 LINE_LABEL_LIST['N3'] = ['1749A', '1754A', '1747A', '1752A', '1744A', '1750A', '990A', '992A', '2280A', '2284A', 
                          '2288A', '2280A', '2283A', '2287A', '763A', '764A', '1356A', '1357A', '3334A', 
                          '3335A', '57.4m', '167.5m', '71.0m', '123.3m', '1492.1m']
@@ -108,6 +135,7 @@ LINE_LABEL_LIST['Ne6'] = ['997A', '1010A', '993A', '1006A', '986A', '999A', '559
                           '1929A', '7.65m', '22.7m', '9.2m', '15.5m', '334.4m']
 LINE_LABEL_LIST['Ni3'] = ['7890A', '8500A', '6000A', '6401A', '6534A', '6682A', '6797A', '7125A', '6946A']
 LINE_LABEL_LIST['O1'] = ['6300A', '6364A', '6392A', '2959A', '2973A', '2979A', '5577A', '63.2m', '44.1m', '145.5m']
+LINE_LABEL_LIST['O1r'] = ['8447+', '7773+', '9264+', '3947+', '1357+']
 LINE_LABEL_LIST['O2'] = ['3729A', '3726A', '2470A', '7319A','7320A', '7330A', '7331A', '2470A', '834A', '1075A', 
                          '1260A', '833A', '1073A', '1258A', '833A', '1072A', '1256A', '499.3m', '5023.7m', '61.3m', 
                          '40.7m', '121.3m']
